==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/test/it/parser/src/main/java/org/apache/shardingsphere/test/it/sql/parser/internal/asserts/segment/generic/DataTypeAssert.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.test.it.sql.parser.internal.asserts.segment.generic;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import org.apache.shardingsphere.sql.parser.statement.core.segment.generic.DataTypeLengthSegment;
import org.apache.shardingsphere.sql.parser.statement.core.segment.generic.DataTypeSegment;
import org.apache.shardingsphere.test.it.sql.parser.internal.asserts.SQLCaseAssertContext;
import org.apache.shardingsphere.test.it.sql.parser.internal.cases.parser.jaxb.segment.impl.generic.ExpectedDataType;
import org.apache.shardingsphere.test.it.sql.parser.internal.cases.parser.jaxb.segment.impl.generic.ExpectedDataTypeLength;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

/**
 *  Data type assert.
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public final class DataTypeAssert {
    
    /**
     * Assert actual data type segment is correct with expected date type.
     *
     * @param assertContext assert context
     * @param actual actual data type statement
     * @param expected expected data type
     */
    public static void assertIs(final SQLCaseAssertContext assertContext, final DataTypeSegment actual, final ExpectedDataType expected) {
        assertThat(assertContext.getText(String.format("%s name assertion error: ", "dataType")),
                actual.getDataTypeName(), is(expected.getValue()));
        assertThat(assertContext.getText(String.format("%s start index assertion error: ", "dataType")),
                actual.getStartIndex(), is(expected.getStartIndex()));
        assertThat(assertContext.getText(String.format("%s end index assertion error: ", "dataType")),
                actual.getStopIndex(), is(expected.getStopIndex()));
        if (null != expected.getDataLength()) {
            DataTypeLengthSegment actualDataLength = actual.getDataLength();
            ExpectedDataTypeLength expectedDataLength = expected.getDataLength();
            if (null != expectedDataLength.getType()) {
                assertThat(assertContext.getText(String.format("%s name assertion error: ", "dataTypeLength")),
                        actualDataLength.getType().get(), is(expectedDataLength.getType()));
            }
            if (null != expectedDataLength.getPrecision()) {
                assertThat(assertContext.getText(String.format("%s name assertion error: ", "dataTypeLength")),
                        actualDataLength.getPrecision(), is(expectedDataLength.getPrecision()));
            }
        }
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/test/it/parser/src/main/java/org/apache/shardingsphere/test/it/sql/parser/internal/asserts/segment/generic/DataTypeAssert.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.test.it.sql.parser.internal.asserts.segment.generic;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import org.apache.shardingsphere.sql.parser.statement.core.segment.generic.DataTypeLengthSegment;
import org.apache.shardingsphere.sql.parser.statement.core.segment.generic.DataTypeSegment;
import org.apache.shardingsphere.test.it.sql.parser.internal.asserts.SQLCaseAssertContext;
import org.apache.shardingsphere.test.it.sql.parser.internal.cases.parser.jaxb.segment.impl.generic.ExpectedDataType;
import org.apache.shardingsphere.test.it.sql.parser.internal.cases.parser.jaxb.segment.impl.generic.ExpectedDataTypeLength;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

/**
 *  Data type assert.
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public final class DataTypeAssert {
    
    /**
     * Assert actual data type segment is correct with expected date type.
     *
     * @param assertContext assert context
     * @param actual actual data type statement
     * @param expected expected data type
     */
    public static void assertIs(final SQLCaseAssertContext assertContext, final DataTypeSegment actual, final ExpectedDataType expected) {
        assertThat(assertContext.getText(String.format("%s name assertion error: ", "dataType")),
                actual.getDataTypeName(), is(expected.getValue()));
        assertThat(assertContext.getText(String.format("%s start index assertion error: ", "dataType")),
                actual.getStartIndex(), is(expected.getStartIndex()));
        assertThat(assertContext.getText(String.format("%s end index assertion error: ", "dataType")),
                actual.getStopIndex(), is(expected.getStopIndex()));
        if (null != expected.getDataLength()) {
            DataTypeLengthSegment actualDataLength = actual.getDataLength();
            ExpectedDataTypeLength expectedDataLength = expected.getDataLength();
            if (null != expectedDataLength.getType()) {
                assertThat(assertContext.getText(String.format("%s name assertion error: ", "dataTypeLength")),
                        actualDataLength.getType().get(), is(expectedDataLength.getType()));
            }
            if (null != expectedDataLength.getPrecision()) {
                assertThat(assertContext.getText(String.format("%s name assertion error: ", "dataTypeLength")),
                        actualDataLength.getPrecision(), is(expectedDataLength.getPrecision()));
            }
        }
    }
}
